@@ -44,7 +44,15 @@ class Instrument:
 			b.key = state["key"]
 			self.bar = b
 
-		self.bar.place_notes(None, state["resolution"])
+		if len(self.bar) > 0:
+			if self.bar[0][2] is None:
+				i = 1 / (1.0 / state["resolution"] + \
+					1.0 / self.bar[0][1])
+				self.bar[0][1] = i
+			else:
+				self.bar.place_notes(None, state["resolution"])
+		else:
+			self.bar.place_notes(None, state["resolution"])
 		self.last_tick = (state["iterations"], state["tick"])
 
 
@@ -79,6 +87,7 @@ class Instrument:
 			if n != None:
 				for note in n:
 					note.dynamics["velocity"] = v
+
 				# Record played notes in a Track
 				if self.last_tick != (state["iterations"], state["tick"]):
 					self.bar.place_notes(n, state["resolution"])
@@ -94,7 +103,15 @@ class Instrument:
 				if state["paint_function"] != None:
 					state["paint_function"](n, self.params["channel"])
 			else:
-				self.bar.place_notes([], state["resolution"])
+				if len(self.bar) > 0:
+					if self.bar[0][2] is None:
+						i = 1 / (1.0 / state["resolution"] + \
+							1.0 / self.bar[0][1])
+						self.bar[0][1] = i
+					else:
+						self.bar.place_notes(None, state["resolution"])
+				else:
+					self.bar.place_notes(None, state["resolution"])
 
 		self.last_tick = (state["iterations"], state["tick"])
 
