@@ -97,6 +97,9 @@ class Sequencer:
 				diff = i.end - i.start
 				i.start = i.end + i.step
 				i.end = i.start + diff
+				i.add_rest(self.state)
+			else:
+				i.add_rest(self.state)
 
 
 	def play(self):
@@ -129,6 +132,7 @@ class Sequencer:
 	def output_midi(self):
 		c = Composition()
 		chan = []
+		print "Writing MIDI file %s..." % self.output_file
 		for s in self.instruments:
 			if hasattr(s, 'bar'):
 				s.track + s.bar
